@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: EUPL-1.2
 
-import holidays
+import holidays  # type: ignore
 from datetime import date, datetime, timedelta
 from dateutil.relativedelta import relativedelta
 from dateutil.tz import gettz
