@@ -85,12 +85,8 @@ class EntityBase(ABC):
 
 
 def _reflect(value):
-    """Reflect on attribute type and return JSON parse-able type.
+    "Reflect on attribute type and return a JSON serializable value."
 
-    :param attr: attribute
-    :return: converted object to correct type
-    :rtype: str, int or None
-    """
     if (
         (value is None)
         or isinstance(value, bool)
@@ -110,7 +106,7 @@ def _reflect(value):
     elif isinstance(value, IntrospectableObject):
         return {k: _reflect(v) for k, v in value.dict().items()}
 
-    if isinstance(value, List):
+    if isinstance(value, (set, list, tuple)):
         return [_reflect(i) for i in value]
 
     if isinstance(value, Enum):
@@ -275,7 +271,7 @@ class Entity(IntrospectableObject):
             if isinstance(v, Entity):
                 rv[k] = v.entity_dict()
             elif isinstance(v, IntrospectableObject):
-                rv[k] = v.dict()
+                rv[k] = v.dict(by_alias=True)
             else:
                 if k.startswith("_") or k.startswith("entity_"):
                     continue
