@@ -3,7 +3,6 @@
 # SPDX-License-Identifier: EUPL-1.2
 
 import json
-import statsd  # type: ignore
 from .exceptions import ValidationError
 from functools import wraps
 from jsonpointer import JsonPointer  # type: ignore
@@ -60,22 +59,21 @@ def validate_with(schema_data: Optional[bytes]):
 
         @wraps(f)
         def check_validity(*args, **kwargs):
-            with statsd.Timer(__name__).time("check_validity"):
-                errors = []
-                for error in validator.iter_errors(instance=kwargs):
-                    error_pointer = JsonPointer.from_parts(error.absolute_path)
+            errors = []
+            for error in validator.iter_errors(instance=kwargs):
+                error_pointer = JsonPointer.from_parts(error.absolute_path)
 
-                    errors.append(
-                        {
-                            "context": error.validator,
-                            "message": error.message,
-                            "cause": str(error.cause) if error.cause else None,
-                            "property": error_pointer.path,
-                        }
-                    )
+                errors.append(
+                    {
+                        "context": error.validator,
+                        "message": error.message,
+                        "cause": str(error.cause) if error.cause else None,
+                        "property": error_pointer.path,
+                    }
+                )
 
-                if len(errors):
-                    raise ValidationError(errors)
+            if len(errors):
+                raise ValidationError(errors)
 
             return f(*args, **kwargs)
 
